==> activity-center-api-1.4.4-20170323.055741-1-sources.jar: cn/com/duiba/activity/center/api/params/RecommendParams.java <==
package cn.com.duiba.activity.center.api.params;

import java.io.Serializable;

/**
 * Created by zhengjy on 2017/2/7.
 */
public class RecommendParams implements Serializable {
    private static final long serialVersionUID = -6452110564483044901L;

    //请求类型：兑换项
    public static final String REQUEST_TYPE_ITEM = "item";
    //请求类型：活动
    public static final String REQUEST_TYPE_ACTIVITY = "activity";

    private Long appId;
    private Long operatingActivityId;

    private String activityIds;//用户已经参加过的活动id，多个“,”逗号隔开

    private Integer recommendShowNum=2;//橱窗位展示几个，默认2个

    private String requestType;//请求类型

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public String getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(String activityIds) {
        this.activityIds = activityIds;
    }

    public Integer getRecommendShowNum() {
        return recommendShowNum;
    }

    public void setRecommendShowNum(Integer recommendShowNum) {
        this.recommendShowNum = recommendShowNum;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }


}

==> activity-center-api-1.4.13-20170414.121004-1-sources.jar: cn/com/duiba/activity/center/api/params/RecommendParams.java <==
package cn.com.duiba.activity.center.api.params;

import java.io.Serializable;

/**
 * Created by zhengjy on 2017/2/7.
 */
public class RecommendParams implements Serializable {
    private static final long serialVersionUID = -6452110564483044901L;

    //请求类型：兑换项
    public static final String REQUEST_TYPE_ITEM = "item";
    //请求类型：活动
    public static final String REQUEST_TYPE_ACTIVITY = "activity";

    private Long appId;
    private Long operatingActivityId;

    private String activityIds;//用户已经参加过的活动id，多个“,”逗号隔开

    private Integer recommendShowNum=2;//橱窗位展示几个，默认2个

    private String requestType;//请求类型
    
    private Integer layout;//布局 1上下 2 左右

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOperatingActivityId() {
        return operatingActivityId;
    }

    public void setOperatingActivityId(Long operatingActivityId) {
        this.operatingActivityId = operatingActivityId;
    }

    public String getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(String activityIds) {
        this.activityIds = activityIds;
    }

    public Integer getRecommendShowNum() {
        return recommendShowNum;
    }

    public void setRecommendShowNum(Integer recommendShowNum) {
        this.recommendShowNum = recommendShowNum;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }

    public Integer getLayout() {
        return layout;
    }

    public void setLayout(Integer layout) {
        this.layout = layout;
    }


}
